## 国债收益率曲线

接口：yc_cb

描述：获取中债收益率曲线，目前可获取中债国债收益率曲线即期和到期收益率曲线数据

限量：单次最大2000，总量不限制，可循环提取

权限：属于单独的权限接口，请在群里联系群主或管理员

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 收益率曲线编码：1001.CB-国债收益率曲线 |
| curve_type | str | N | 曲线类型：0-到期，1-即期 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 查询起始日期 |
| end_date | str | N | 查询结束日期 |
| curve_term | float | N | 期限 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | 曲线编码 |
| curve_name | str | Y | 曲线名称 |
| curve_type | str | Y | 曲线类型：0-到期，1-即期 |
| curve_term | float | Y | 期限(年) |
| yield | float | Y | 收益率(%) |

接口示例

```python
pro = ts.pro_api(your token)
#获取中债收益率曲线
df = pro.yc_cb(ts_code='1001.CB',curve_type='0',trade_date='20200203')
```

数据示例

```python
trade_date ts_code curve_name curve_type curve_term     yield
0      20200203        101  中债国债收益率曲线          0     0.0000  1.697300
```